




******

Bravo!  You have received a Mercantilism Diploma in "fortunes" from   
the Orbital Convergence University International Air and Water 
Embassy of the 🍊 Planet (the planet that is one ellipse further from
the Sun than Earth's ellipse).

You are now officially certified to include "fortunes" in your practice.

******

# ☄️ fortunes
🎼🎵🎶   

## 🔮 taps (OCHLV)
taps.season_3.super_hero_trend   
	
## 🎭 stats (options)
stats.aggregate_break_even   
stats.aggregate_PC_ratio    


## 🌩️ clouds
clouds.Coinbase.API.products.candles